CheetahTranscriptAnnotated class

Constructors

CheetahTranscriptAnnotated(String? _transcript, List<CheetahWord>? _words, bool? _isEndpoint)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isEndpoint → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transcript → String
no setter
words → List<CheetahWord>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited