CheetahWord class

Constructors

CheetahWord(String word, double startSeconds, double endSeconds, double confidence)

Properties

confidence → double
final
endSeconds → double
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startSeconds → double
final
word → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited