Cheetah class
Properties
- frameLength → int
-
The number of audio samples per frame required by Cheetah
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleRate → int
-
The audio sample rate required by Cheetah
no setter
- version → String
-
Cheetah version string
no setter
Methods
-
delete(
) → Future< void> - Frees memory that was allocated for Cheetah
-
flush(
) → Future< CheetahTranscript> - Processes any remaining audio data and returns its transcription.
-
flushAnnotated(
) → Future< CheetahTranscriptAnnotated> - Processes any remaining audio data and returns its transcription.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
process(
List< int> ? frame) → Future<CheetahTranscript> - Process a frame of pcm audio with the speech-to-text engine.
-
processAnnotated(
List< int> ? frame) → Future<CheetahTranscriptAnnotated> - Process a frame of pcm audio with the speech-to-text engine.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
String accessKey, String modelPath, {String device = "best", double endpointDuration = 1, dynamic enableAutomaticPunctuation = false, dynamic enableTextNormalization = false}) → Future< Cheetah> - Static creator for initializing Cheetah
-
getAvailableDevices(
) → Future< List< String> > -
Lists all available devices that Cheetah can use for inference.
Entries in the list can be used as the
deviceargument when initializing Cheetah.